import {
  mailgunConfig,
  mailjetConfig,
  mailJsConfig,
  mandrillConfig,
  netCoreConfig,
  nodemailerConfig,
  postmarkConfig,
  sendgridConfig,
  sendinblueConfig,
  sesConfig,
} from '../provider-credentials';
import { IProviderConfig } from '../provider.interface';
import { ChannelTypeEnum } from '../../../entities/message-template';

export const emailProviders: IProviderConfig[] = [
  {
    id: 'emailjs',
    displayName: 'Email.js',
    channel: ChannelTypeEnum.EMAIL,
    credentials: mailJsConfig,
    docReference: 'https://www.emailjs.com/docs/',
    logoFileName: { light: 'emailjs.svg', dark: 'emailjs.svg' },
  },
  {
    id: 'mailgun',
    displayName: 'Mailgun',
    channel: ChannelTypeEnum.EMAIL,
    credentials: mailgunConfig,
    docReference: 'https://documentation.mailgun.com/en/latest/',
    logoFileName: { light: 'mailgun.svg', dark: 'mailgun.svg' },
  },
  {
    id: 'mailjet',
    displayName: 'Mailjet',
    channel: ChannelTypeEnum.EMAIL,
    credentials: mailjetConfig,
    docReference: 'https://documentation.mailjet.com/hc/en-us/categories/360003942934-Mailjet-Documentation-Center-',
    logoFileName: { light: 'mailjet.png', dark: 'mailjet.png' },
  },
  {
    id: 'mandrill',
    displayName: 'Mandrill',
    channel: ChannelTypeEnum.EMAIL,
    credentials: mandrillConfig,
    docReference: 'https://mandrillapp.com/docs/?_ga=1.34114145.1141874178.1422518109',
    logoFileName: { light: 'mandrill.svg', dark: 'mandrill.svg' },
  },
  {
    id: 'nodemailer',
    displayName: 'Nodemailer',
    channel: ChannelTypeEnum.EMAIL,
    credentials: nodemailerConfig,
    docReference: 'https://nodemailer.com/about/',
    logoFileName: { light: 'nodemailer.svg', dark: 'nodemailer.svg' },
  },
  {
    id: 'postmark',
    displayName: 'Postmark',
    channel: ChannelTypeEnum.EMAIL,
    credentials: postmarkConfig,
    docReference: 'https://postmarkapp.com/developer',
    logoFileName: { light: 'postmark.png', dark: 'postmark.png' },
  },
  {
    id: 'sendgrid',
    displayName: 'SendGrid',
    channel: ChannelTypeEnum.EMAIL,
    credentials: sendgridConfig,
    docReference: 'https://docs.sendgrid.com/',
    logoFileName: { light: 'sendgrid.png', dark: 'sendgrid.png' },
  },
  {
    id: 'sendinblue',
    displayName: 'Sendinblue',
    channel: ChannelTypeEnum.EMAIL,
    credentials: sendinblueConfig,
    docReference: 'https://www.sendinblue.com/',
    logoFileName: { light: 'sendinblue.png', dark: 'sendinblue.png' },
  },
  {
    id: 'ses',
    displayName: 'SES',
    channel: ChannelTypeEnum.EMAIL,
    credentials: sesConfig,
    docReference: 'https://docs.aws.amazon.com/ses/index.html',
    logoFileName: { light: 'ses.svg', dark: 'ses.svg' },
  },
  {
    id: 'netcore',
    displayName: 'NetCore',
    channel: ChannelTypeEnum.EMAIL,
    credentials: netCoreConfig,
    docReference: 'https://netcorecloud.com/email/email-api/',
    logoFileName: { light: 'netcore.png', dark: 'netcore.png' },
  },
];
